@@ -78,16 +78,6 @@ class HeadingSensorFilter(deeding.LapseDeed):
         super(HeadingSensorFilter,self).__init__(**kw)  
 
     
-    def preinitio(self,  **kw):
-        """ Parse-time re-initio
-            This just prints warning for now since not yet supported by this class.
-            
-        """
-        console.terse("     Warning: Parse time init not supported on this deed"
-                      " '{0}'\n".format(self.name))
-        return self    
-        
-    
     def initio(self, group, output, input, scenario, parms = None, **kw):
         """ Override since legacy init interface
         
@@ -206,17 +196,6 @@ class WindowedFilter(deeding.LapseDeed):
         super(WindowedFilter,self).__init__(**kw)  
 
     
-    def preinitio(self,  **kw):
-        """ Parse-time re-initio
-            This just prints warning for now since not yet supported by this class.
-            
-        """
-        console.terse("     Warning: Parse time init not supported on this deed"
-                      " '{0}'\n".format(self.name))
-        return self    
-        
-
-    
     def initio(self, group, output, input, field, depth, parms = None, **kw):
         """ Override since legacy init interface
         
@@ -358,16 +337,6 @@ class MinCTDFilter(deeding.LapseDeed):
         super(MinCTDFilter,self).__init__(**kw)  
 
     
-    def preinitio(self,  **kw):
-        """ Parse-time re-initio
-            This just prints warning for now since not yet supported by this class.
-            
-        """
-        console.terse("     Warning: Parse time init not supported on this deed"
-                      " '{0}'\n".format(self.name))
-        return self    
-        
-    
     def initio(self, group, outputs, output, input, field, depth, position, parms = None, **kw):
         """ Override since legacy init interface
         
